==> jc-1.4.0.tar.gz: gnu/xml/dom/DomNotation.h <==
// public class gnu.xml.dom.DomNotation

// class file dependencies
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 5b5336c9987ffef5 gnu_xml_dom_DomNode
// @dep_class 178f419a3dac78fd gnu_xml_dom_DomNotation
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomExtern

#include "gnu/xml/dom/DomExtern.h"

#ifndef _JC_gnu_xml_dom_DomNotation_H_
#define _JC_gnu_xml_dom_DomNotation_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNotation$sub_refs	_jc_gnu_xml_dom_DomNotation$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNotation$sub_nonrefs	_jc_gnu_xml_dom_DomNotation$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNotation$refs	_jc_gnu_xml_dom_DomNotation$refs;
typedef struct _jc_gnu_xml_dom_DomNotation$nonrefs	_jc_gnu_xml_dom_DomNotation$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNotation$object	_jc_gnu_xml_dom_DomNotation$object;

typedef const struct _jc_gnu_xml_dom_DomNotation$vmethods	_jc_gnu_xml_dom_DomNotation$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNotation$vtable	_jc_gnu_xml_dom_DomNotation$vtable;
typedef const struct _jc_gnu_xml_dom_DomNotation$vtype	_jc_gnu_xml_dom_DomNotation$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNotation$method$_init$aa3022bed942b6b4(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNotation$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNotation$method_info$getBaseURI$1b139395df599840;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNotation$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomNotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
	_jc_gnu_xml_dom_DomNotation$vmethods	gnu_xml_dom_DomNotation;
};

// Vtype
struct _jc_gnu_xml_dom_DomNotation$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNotation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNotation$refs {
    _jc_gnu_xml_dom_DomNotation$sub_refs	gnu_xml_dom_DomNotation;
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNotation$sub_nonrefs	gnu_xml_dom_DomNotation;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNotation$object {
	_jc_gnu_xml_dom_DomNotation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNotation$vtype	*vtype;
	_jc_gnu_xml_dom_DomNotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNotation$vtype _jc_gnu_xml_dom_DomNotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNotation$class_object;

#endif	/* _JC_gnu_xml_dom_DomNotation_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/dom/DomNotation.h <==
// public class gnu.xml.dom.DomNotation

// class file dependencies
// @dep_class 927ff3b1d72554f gnu_xml_dom_DomExtern
// @dep_class 4ec94c6db3eac49b gnu_xml_dom_DomNode
// @dep_class 178f419a3dac78fd gnu_xml_dom_DomNotation
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_DomExtern

#include "gnu/xml/dom/DomExtern.h"

#ifndef _JC_gnu_xml_dom_DomNotation_H_
#define _JC_gnu_xml_dom_DomNotation_H_

// Forward structure declarations
struct _jc_gnu_xml_dom_DomDocument$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomNotation$sub_refs	_jc_gnu_xml_dom_DomNotation$sub_refs;
typedef struct _jc_gnu_xml_dom_DomNotation$sub_nonrefs	_jc_gnu_xml_dom_DomNotation$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomNotation$refs	_jc_gnu_xml_dom_DomNotation$refs;
typedef struct _jc_gnu_xml_dom_DomNotation$nonrefs	_jc_gnu_xml_dom_DomNotation$nonrefs;
typedef struct _jc_gnu_xml_dom_DomNotation$object	_jc_gnu_xml_dom_DomNotation$object;

typedef const struct _jc_gnu_xml_dom_DomNotation$vmethods	_jc_gnu_xml_dom_DomNotation$vmethods;
typedef const struct _jc_gnu_xml_dom_DomNotation$vtable	_jc_gnu_xml_dom_DomNotation$vtable;
typedef const struct _jc_gnu_xml_dom_DomNotation$vtype	_jc_gnu_xml_dom_DomNotation$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomNotation$method$_init$aa3022bed942b6b4(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *, struct _jc_gnu_xml_dom_DomDocument$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomNotation$method$getBaseURI$1b139395df599840(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomNotation$method_info$getBaseURI$1b139395df599840;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomNotation$vmethods {
	struct _jc_java_lang_String$object	*(*getBaseURI$1b139395df599840)(_jc_env *, struct _jc_gnu_xml_dom_DomNotation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomNotation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomNode$vmethods	gnu_xml_dom_DomNode;
	_jc_gnu_xml_dom_DomExtern$vmethods	gnu_xml_dom_DomExtern;
	_jc_gnu_xml_dom_DomNotation$vmethods	gnu_xml_dom_DomNotation;
};

// Vtype
struct _jc_gnu_xml_dom_DomNotation$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomNotation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNotation$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomNotation$refs {
    _jc_gnu_xml_dom_DomNotation$sub_refs	gnu_xml_dom_DomNotation;
    _jc_gnu_xml_dom_DomExtern$sub_refs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNode$sub_refs	gnu_xml_dom_DomNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomNotation$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomNotation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomNode$sub_nonrefs	gnu_xml_dom_DomNode;
    _jc_gnu_xml_dom_DomExtern$sub_nonrefs	gnu_xml_dom_DomExtern;
    _jc_gnu_xml_dom_DomNotation$sub_nonrefs	gnu_xml_dom_DomNotation;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomNotation$object {
	_jc_gnu_xml_dom_DomNotation$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomNotation$vtype	*vtype;
	_jc_gnu_xml_dom_DomNotation$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomNotation$vtype _jc_gnu_xml_dom_DomNotation$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomNotation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomNotation$class_object;

#endif	/* _JC_gnu_xml_dom_DomNotation_H_ */
